@@ -44,6 +44,22 @@ private Q_SLOTS:
         QTest::newRow("ic-no-platform-data")
             << s(SOURCE_DIR "/data/oebb/ic-no-platform-data-input.json")
             << s(SOURCE_DIR "/data/oebb/ic-no-platform-data-departure.json");
+
+        QTest::newRow("regionalexpress")
+            << s(SOURCE_DIR "/data/oebb/regional-express-input.json")
+            << s(SOURCE_DIR "/data/oebb/regional-express-departure.json");
+
+        QTest::newRow("sbahn")
+            << s(SOURCE_DIR "/data/oebb/sbahn-input.json")
+            << s(SOURCE_DIR "/data/oebb/sbahn-departure.json");
+
+        QTest::newRow("nightjet")
+            << s(SOURCE_DIR "/data/oebb/nightjet-input.json")
+            << s(SOURCE_DIR "/data/oebb/nightjet-departure.json");
+
+        QTest::newRow("per-coach-occupancy")
+            << s(SOURCE_DIR "/data/oebb/rjx-per-coach-occupancy-input.json")
+            << s(SOURCE_DIR "/data/oebb/rjx-per-coach-occupancy-departure.json");
     }
 
     void testVehicleLayoutParse()
