@@ -41,6 +41,8 @@
 #include "backends/openjourneyplannerbackend.h"
 #include "backends/opentripplannergraphqlbackend.h"
 #include "backends/opentripplannerrestbackend.h"
+#include "backends/pasazieruvilciensbackend.h"
+#include "backends/ltglinkbackend.h"
 #include "gbfs/gbfsbackend.h"
 
 #include <QDirIterator>
@@ -182,7 +184,9 @@ std::unique_ptr<AbstractBackend> ManagerPrivate::loadNetwork(const QJsonObject &
         IvvAssBackend,
         OpenJourneyPlannerBackend,
         GBFSBackend,
-        AccessibilityCloudBackend
+        AccessibilityCloudBackend,
+        PasazieruVilciensBackend,
+        LTGLinkBackend
     >(type, obj);
 }
 
